@@ -1,4 +1,4 @@
-//@line 45 "/usr/obj/i386/firefox35-3.5.11/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/usr/obj/ports/firefox35-3.5.16/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -245,7 +245,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 301 "/usr/obj/i386/firefox35-3.5.11/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 301 "/usr/obj/ports/firefox35-3.5.16/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -409,6 +409,7 @@ function Startup()
             getService(Ci.nsIObserverService);
   obs.addObserver(gDownloadObserver, "download-manager-remove-download", false);
   obs.addObserver(gDownloadObserver, "private-browsing", false);
+  obs.addObserver(gDownloadObserver, "browser-lastwindow-close-granted", false);
 
   // Clear the search box and move focus to the list on escape from the box
   gSearchBox.addEventListener("keypress", function(e) {
@@ -428,6 +429,7 @@ function Shutdown()
             getService(Ci.nsIObserverService);
   obs.removeObserver(gDownloadObserver, "private-browsing");
   obs.removeObserver(gDownloadObserver, "download-manager-remove-download");
+  obs.removeObserver(gDownloadObserver, "browser-lastwindow-close-granted");
 
   clearTimeout(gBuilder);
   gStmt.reset();
@@ -471,6 +473,13 @@ let gDownloadObserver = {
           }, 0);
         }
         break;
+      case "browser-lastwindow-close-granted":
+//@line 530 "/usr/obj/ports/firefox35-3.5.16/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
+        if (gDownloadManager.activeDownloadCount == 0) {
+          setTimeout(gCloseDownloadManager, 0);
+        }
+//@line 534 "/usr/obj/ports/firefox35-3.5.16/mozilla-1.9.1/toolkit/mozapps/downloads/content/downloads.js"
+        break;
     }
   }
 };
